pub struct ParallelStreamingParser<R: Read + Send + Sync> { /* private fields */ }Available on crate feature
parallel only.Expand description
Parallel streaming parser for processing large files without loading entirely into memory
Implementations
Sourceimpl<R: Read + Send + Sync + 'static> ParallelStreamingParser<R>
impl<R: Read + Send + Sync + 'static> ParallelStreamingParser<R>
Sourcepub fn with_config(reader: R, config: ParallelConfig) -> Self
pub fn with_config(reader: R, config: ParallelConfig) -> Self
Create a parallel streaming parser with custom configuration
Sourcepub fn process_batches<F>(&mut self, processor: F) -> TurtleResult<usize>
pub fn process_batches<F>(&mut self, processor: F) -> TurtleResult<usize>
Process the file in parallel batches
This reads batches from the file and processes them in parallel.