PatchChange

Enum PatchChange 

pub enum PatchChange {
    AddPrefix {
        prefix: String,
        iri: String,
    },
    DeletePrefix {
        prefix: String,
        iri: String,
    },
    AddTriple(PatchTriple),
    DeleteTriple(PatchTriple),
    AddQuad(PatchQuad),
    DeleteQuad(PatchQuad),
    TransactionBegin,
    TransactionCommit,
    TransactionAbort,
}
A single change line in an RDF Patch document

Variants



AddPrefix

PA prefix <iri> — add a prefix declaration

Fields

prefix: String

Namespace prefix label

iri: String

IRI bound to the prefix



DeletePrefix

PD prefix <iri> — delete a prefix declaration

Fields

prefix: String

Namespace prefix label

iri: String

IRI bound to the prefix



AddTriple(PatchTriple)

A <s> <p> <o> . — add a triple



DeleteTriple(PatchTriple)

D <s> <p> <o> . — delete a triple



AddQuad(PatchQuad)

A <s> <p> <o> <g> . — add a quad



DeleteQuad(PatchQuad)

D <s> <p> <o> <g> . — delete a quad



TransactionBegin

TX — begin a transaction block



TransactionCommit

TC — commit a transaction block



TransactionAbort

TA — abort a transaction block

Implementations

Source

impl PatchChange

pub fn line_prefix(&self) -> &'static str

Return the line prefix that represents this change in the patch format

pub fn is_add(&self) -> bool

Return true if this change adds data

pub fn is_delete(&self) -> bool

Return true if this change deletes data

pub fn is_transaction_control(&self) -> bool

Return true if this is a transaction control statement