pub struct BufferStats {
pub total_acquisitions: usize,
pub pool_hits: usize,
pub pool_misses: usize,
pub total_releases: usize,
pub current_pool_size: usize,
}Expand description
Statistics about buffer pool usage
Fields
total_acquisitions: usizeTotal number of buffer acquisitions
pool_hits: usizeNumber of times a buffer was reused from pool (hit)
pool_misses: usizeNumber of times a new buffer was allocated (miss)
total_releases: usizeTotal number of buffer releases
current_pool_size: usizeCurrent number of buffers in the pool
Implementations