pub struct MappingEngine {
pub skip_errors: bool,
}Expand description
Engine that executes MappingRules and produces RDF Triples
The engine is stateless and cheap to create. All configuration is carried by the rules themselves.
Fields
skip_errors: boolWhether to skip rows that produce errors instead of failing fast
Implementations
Sourceimpl MappingEngine
impl MappingEngine
Sourcepub fn new_lenient() -> Self
pub fn new_lenient() -> Self
Create an engine that silently skips rows that produce mapping errors
Sourcepub fn execute(&self, rule: &MappingRule) -> MappingResult<Vec<Triple>>
pub fn execute(&self, rule: &MappingRule) -> MappingResult<Vec<Triple>>
Execute a single mapping rule and return all produced triples
Sourcepub fn execute_all(&self, rules: &[MappingRule]) -> MappingResult<Vec<Triple>>
pub fn execute_all(&self, rules: &[MappingRule]) -> MappingResult<Vec<Triple>>
Execute multiple rules and concatenate all produced triples
Sourcepub fn parse_csv(
content: &str,
delimiter: char,
) -> MappingResult<(Vec<String>, Vec<Row>)>
pub fn parse_csv( content: &str, delimiter: char, ) -> MappingResult<(Vec<String>, Vec<Row>)>
Parse CSV content into (headers, rows).
Handles:
- Configurable delimiter
- Double-quote escaping (
""inside a quoted field) - CRLF and LF line endings
- Quoted fields that span multiple lines
Sourcepub fn parse_json(
content: &str,
json_path: Option<&str>,
) -> MappingResult<Vec<Row>>
pub fn parse_json( content: &str, json_path: Option<&str>, ) -> MappingResult<Vec<Row>>
Parse JSON content into rows.
Behaviour:
- If
json_pathisNone, the root must be a JSON array of objects. - If
json_pathisSome("a.b.c"), the engine traverses object keysa→b→cand expects to find an array there. - Each array element must be a JSON object; its key-value pairs become the row fields (values are coerced to strings).