pub enum PatchChange {
AddPrefix {
prefix: String,
iri: String,
},
DeletePrefix {
prefix: String,
iri: String,
},
AddTriple(PatchTriple),
DeleteTriple(PatchTriple),
AddQuad(PatchQuad),
DeleteQuad(PatchQuad),
TransactionBegin,
TransactionCommit,
TransactionAbort,
}Expand description
A single change line in an RDF Patch document
Variants
AddPrefix
PA prefix <iri> — add a prefix declaration
DeletePrefix
PD prefix <iri> — delete a prefix declaration
AddTriple(PatchTriple)
A <s> <p> <o> . — add a triple
DeleteTriple(PatchTriple)
D <s> <p> <o> . — delete a triple
AddQuad(PatchQuad)
A <s> <p> <o> <g> . — add a quad
DeleteQuad(PatchQuad)
D <s> <p> <o> <g> . — delete a quad
TransactionBegin
TX — begin a transaction block
TransactionCommit
TC — commit a transaction block
TransactionAbort
TA — abort a transaction block
Implementations
Sourceimpl PatchChange
impl PatchChange
Sourcepub fn line_prefix(&self) -> &'static str
pub fn line_prefix(&self) -> &'static str
Return the line prefix that represents this change in the patch format
Sourcepub fn is_transaction_control(&self) -> bool
pub fn is_transaction_control(&self) -> bool
Return true if this is a transaction control statement