pub struct PatchTerm(pub RdfTerm);Expand description
A subject/object position that accepts either a named node, blank node, or literal. Used internally for parsed term positions.
Tuple Fields
0: RdfTermImplementations
Sourceimpl PatchTerm
impl PatchTerm
Sourcepub fn iri(iri: impl Into<String>) -> Self
pub fn iri(iri: impl Into<String>) -> Self
Create from an IRI (angle-bracket or prefixed form, already resolved)
Sourcepub fn blank_node(id: impl Into<String>) -> Self
pub fn blank_node(id: impl Into<String>) -> Self
Create from a blank node identifier
Sourcepub fn lang_literal(value: impl Into<String>, lang: impl Into<String>) -> Self
pub fn lang_literal(value: impl Into<String>, lang: impl Into<String>) -> Self
Create from a language-tagged literal
Sourcepub fn typed_literal(
value: impl Into<String>,
datatype: impl Into<String>,
) -> Self
pub fn typed_literal( value: impl Into<String>, datatype: impl Into<String>, ) -> Self
Create from a typed literal
Sourcepub fn is_blank_node(&self) -> bool
pub fn is_blank_node(&self) -> bool
Return true if this term is a blank node